Built-in Violations
===================

Violations are holmes' way of telling you something is not right with a given page in your website.

A violation is composed of key, title, description and points. The reason we have different points for different violations i
